const express = require('express')
const http = require('http')
const bodyParser = require('body-parser')
const app = express()
const port = process.env.port || 3999

const env = ['development', 'test', 'production', 'unittest']

if (!~env.indexOf(process.env.NODE_ENV)) {
  console.error(
    `
      FATAL: environmental variable required, must be of development、test、production or unittest.
         eg: NODE_ENV=development node xxx.js
    `
  )
  process.exit(1)
}

/**
 * Log is a property of the global object,
 * so the dependency on Log should be in front of other dependencies
 */
require('./lib/log.js')

const router = require('./routers')

app.use(bodyParser.json())
app.use(bodyParser.urlencoded({ extended: false }))

app.use(require('./middlewares/cors.js'))

app.use(require('./middlewares/requestLog.js'))

app.use(router)

app.set('etag', false)

app.use((err, req, res, next) => {
  Log.error('error:', err)
  res.status(500).json({code: 1, msg: 'something broken.'})
})

http.createServer(app).listen(port, function () {
  Log.app('jj-proxy server start', {port: port})
})
