const winston = require('winston')

const logConfig = {
  levels: {
    fatal: 0,
    error: 1,
    warn: 2,
    app: 3,
    data: 4,
    debug: 5
  },
  colors: {
    fatal: 'bold red whiteBG',
    error: 'red',
    warn: 'yellow',
    app: 'magenta',
    data: 'green',
    debug: 'blue'
  }
}

const logger = winston.createLogger({
  levels: logConfig.levels,
  level: 'data',
  format: winston.format.combine(
    winston.format.timestamp({format: 'YYYY-MM-DD HH:mm:ss:SSS'}),
    winston.format.json()
  ),
  transports: [
    new winston.transports.File({ filename: 'error.log', level: 'error' }),
    new winston.transports.File({ filename: 'combined.log' })
  ],
  exceptionHandlers: [
    new winston.transports.File({ filename: 'exceptions.log' })
  ]
})

if (process.env.NODE_ENV !== 'production') {
  winston.addColors(logConfig.colors)

  logger.add(new winston.transports.Console({
    level: 'debug',
    format: winston.format.combine(
      winston.format.colorize(),
      winston.format.simple()
    )
  }))
}

// By default, winston will exit after logging an uncaughtException.
// If this is not the behavior you want, set exitOnError = false
logger.exitOnError = false

// Because the log tool is too generic,
// it is mounted on a global object
global.Log = logger
