/**
 * @api {get} /sample/get sample
 * @apiName sample get
 * @apiGroup sample
 *
 * @apiParam {String} name 姓名
 *
 * @apiParamExample {json} Request-Example:
 * {
 *    name: 'jarone'
 * }
 *
 * @apiSuccess {Number} code result status(0 : succeed，other : failed)
 * @apiSuccess {String} msg  result description
 * @apiSuccess {String} info result data
 *
 * @apiSuccessExample {json} Success-Response:
 * {
 *    code : 0,
 *    msg  : 'success',
 *    info : 'hello jarone'
 * }
 *
 */
function get (req, res) {
  return res.json({code: 0, msg: 'success', info: `hello ${req.query.name}`})
}

/**
 * @api {post} /sample/post sample
 * @apiName sample post
 * @apiGroup sample
 *
 * @apiParam {String} name 姓名
 *
 * @apiParamExample {json} Request-Example:
 * {
 *    name: 'jarone'
 * }
 *
 * @apiSuccess {Number} code result status(0 : succeed，other : failed)
 * @apiSuccess {String} msg  result description
 * @apiSuccess {String} info result data
 *
 * @apiSuccessExample {json} Success-Response:
 * {
 *    code : 0,
 *    msg  : 'success',
 *    info : 'hello jarone'
 * }
 *
 */
function post (req, res) {
  return res.json({code: 0, msg: 'success', info: `hello ${req.body.name}`})
}

const prefix = '/sample'

module.exports = [
  {
    method: 'get',
    uri: prefix + '/get',
    action: get
  },
  {
    method: 'post',
    uri: prefix + '/post',
    action: post
  }
]
